#
# spec file for package python-pysmb
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pysmb
Version:        1.2.9.1
Release:        1.5
Summary:        SMB/CIFS library to support file sharing between Windows and Linux machines
License:        Zlib
Group:          Development/Languages/Python
URL:            https://miketeo.net/projects/pysmb
Source:         https://files.pythonhosted.org/packages/source/p/pysmb/pysmb-%{version}.zip
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-pyasn1
BuildArch:      noarch
# SECTION test requirements
%if 0%{?sle_version} && 0%{?sle_version} <= 150400
BuildRequires:  python-nose
BuildRequires:  python-twisted
%endif
BuildRequires:  %{python_module nose2}
BuildRequires:  %{python_module pyasn1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module tqdm}
# /SECTION
%python_subpackages

%description
pysmb is an experimental SMB/CIFS library written in Python. It implements the client-side SMB/CIFS protocol which allows your Python application to access and transfer files to/from SMB/CIFS shared folders like your Windows file sharing and Samba folders.

%prep
%autosetup -p1 -n pysmb-%{version}

sed -Ei "1{/^#!\/usr\/bin\/python/d}" python*/smb/*/sha256.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
rm python3/tests/SMBConnectionTests/test_SMBHandler.py
%{python_expand # Run only the tests that can work without network (and only from the right python[2,3] dir)
python_testdir_str=$python
python_testdir=${python_testdir_str:0:7}
export PYTHONPATH=%{$python_sitelib} PYTHONDONTWRITEBYTECODE=1
find . -name \*.pyc\* -delete
pytest-%{$python_bin_suffix} ${python_testdir} -k 'not (SMB or test_broadcast)'
}

%files %{python_files}
%doc CHANGELOG README.txt
%license LICENSE
%{python_sitelib}/smb/
%{python_sitelib}/nmb/
%{python_sitelib}/pysmb-%{version}-py%{python_version}.egg-info/

%changelog
* Fri Jan 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.9.1:
  * Add support for tqdm progress display (gh#miketeo/pysmb#205).
  * Fix bug where timeout parameter was not passed to
    socket.createConnection() (gh#miketeo/pysmb#202).
- BuildRequires: python-tqdm for tests.
* Wed Jun 22 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.8:
  * Fix issue with listPath based on recommendation.
  * Fix embedded MD4 algorithm.
  * Add SMB UTF-16 surrogate exception workaround policy.
- Drop fix-smbconnection-tests.patch: incorporated upstream.
- Delete a test file that has incorrect imports and is not needed.
* Fri Feb  4 2022 Matej Cepl <mcepl@suse.com>
- Fix testing on older Leap versions.
* Wed Feb  2 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.7:
  * Fix compatibility issues on file retrievals with Likewise servers (#177)
  * Improve SMBConnection's connect() method to remove the need to provide
    sock_family parameter for IPv6 addresses in Python 3.x (#180)
- Add patch fix-smbconnection-tests.patch:
  * Use correct nose 2 decorators
* Sat Jan 16 2021 Benjamin Greiner <code@bnavigator.de>
- Fix test suite call
* Sat Dec 12 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.6:
  * Fix bug in SMB1 store file implmentation which generates
    SMB_COM_WRITE_ANDX packets larger than the allowed max buffer
    size (gh#miketeo/pysmb#175).
* Sun Oct 25 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.5:
  * Fix bug in filename encoding which leads to failure for file
    retrieval and upload operations (gh#miketeo/pysmb#170,
    gh#miketeo/pysmb#171).
  * Improve resetFileAttributes() method in SMBConnection class to
    allow the new attribute to be specified in the reset operation
    (gh#miketeo/pysmb#172).
- Use pytest to run tests (only those that don't require a network
  connection); BuildRequires:
  python-pytest, python-nose, and for python2 only python-twisted.
* Wed Oct 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.4:
  * Remove dependency on pycrypto as it is no longer under active
    maintenance and use own implementation of RC4 cipher instead
    (gh#miketeo/pysmb#167).
- Changes from version 1.2.3:
  * Fix bug in session key generation during session negotiation
    (gh#miketeo/pysmb#166).
  * Fix bug in SMB message signing which leads to operation
    failures with Samba services.
* Sun Sep  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.2:
  * Improve SMB URL handlers to support specifying server's
    machine name and IP address (gh#miketeo/pysmb#162).
  * Improvements to documentation on SMB URLs
    (gh#miketeo/pysmb#160).
* Sat Aug  1 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.1:
  * Fix bug in deleteFiles() method which can fail for certain
    search patterns.
- Changes from version 1.2.0:
  * Add new parameter, delete_matching_folders, to deleteFiles()
    method to support deletion of child folders that match the
    search pattern.
* Thu May  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Remove python-flavour dependent recompilation commands; they
  are no longer needed for openSUSE >= 1550.
* Thu Nov  8 2018 alarrosa@suse.com
- Remove unneeded python devel package
- Add %%license tag
* Wed Sep 12 2018 badshah400@gmail.com
- Fix mtime difference between object files and sources by
  recompiling after source file modification post python_install
  stage; oddly fdupes needs to be run twice for this to correctly
  work: once before compilation and once after.
* Wed Aug 22 2018 badshah400@gmail.com
- Initial package.
